@@ -93,6 +93,17 @@ class CharacterUnicodeCategoryReplacer(IPreprocessor):
             return cat[0].lower()
 
 
+class UnicodeNormalizer(IPreprocessor):
+    def __init__(self, form: str = "NFKC") -> None:
+        """
+        Valid values for form are ‘NFC’, ‘NFKC’, ‘NFD’, and ‘NFKD’.
+        """
+        self.form = form
+
+    def preprocess(self, string_: str) -> str:
+        return unicodedata.normalize(self.form, string_)
+
+
 class SoftTextScissors(Replacer):
     """Cuts the end of the string in a 'soft' manner: the first whitespace after the 'soft_length' is
     sought for in reach of 'window' size rightwards. If no whitespace is present in the window, then
@@ -803,6 +814,7 @@ class DefaultPreprocessorStack(StackingPreprocessor):
             HtmlEntitiesUnescaper(),
             BoldTagReplacer(),
             HtmlTagReplacer(' '),
+            UnicodeNormalizer(),
             URLReplacer(' urlTag '),
             VKMentionReplacer(' vkMentionTag '),
             EmailReplacer(' emailTag '),
